<?php

namespace USKit\Base\ViewModels;

use USKit\Base\Parts\ArticleBodyPresentation;
use USKit\Base\Parts\NewsMLArticle;
use USKit\Base\Parts\Image;
use Infomaker\Everyware\Support\Interfaces\PropertyObject;

/**
 * Class ArticlePage
 * @package USKit\Base
 */
class ArticlePage extends Page
{
    public function __construct(PropertyObject $article)
    {
        $articleBody = $article->getParsedBody();

        $article->fill([
            'body' => implode($articleBody->generateContent(new ArticleBodyPresentation($article))),
            'teaserImage' => $this->getTeaserImage($article)
        ]);

        parent::__construct($article);
    }

    private function getTeaserImageViewData($teaser) {
        $image = $teaser ? $teaser->getImage() : null;

        if ($image !== null) {
            $image->set('text', $teaser->title);
            $image = new Image($image);
        }

        return $image ? $image->getViewData() : null;
    }

    protected function getTeaserImage(NewsMLArticle $article)
    {
        return $this->getTeaserImageViewData($article->getNewsMLTeaser());
    }

}